SystemOrganization addCategory: #GODCallTests!

Object subclass: #FakeConfSearchFetcher
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!FakeConfSearchFetcher methodsFor: 'fetching' stamp: 'cms 11/22/2014 14:14'!
fetch: url
	|mockPath|
	mockPath := './GODCallTests_data/confsearchpage.html'.	
      ^ (StandardFileStream fileNamed: mockPath ) contentsOfEntireFile.	
	! !

Object subclass: #FakeWikiCfpFetcher
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!FakeWikiCfpFetcher methodsFor: 'fetching' stamp: 'pfsm 11/22/2014 21:07'!
fetch: anUrlString
"comment stating purpose of message"

	|mockPath|

	(anUrlString = 'http://www.wikicfp.com/cfp/call?conference=theoretical%20computer%20science&page=1')
		ifTrue:	[ 	mockPath:= './GODCallTests_data/TCS_WikiCFP.html'.
						^(StandardFileStream fileNamed: mockPath )contentsOfEntireFile
					].

	(anUrlString = 'http://www.wikicfp.com/cfp/servlet/event.showcfp?eventid=41585&copyownerid=42133')
		ifTrue:	[ 	mockPath:= './GODCallTests_data/CADE_WikiCFP.html'.
						^(StandardFileStream fileNamed: mockPath )contentsOfEntireFile
					].

	(anUrlString = 'http://www.wikicfp.com/cfp/servlet/event.showcfp?eventid=39782&copyownerid=320')
		ifTrue:	[ 	mockPath:= './GODCallTests_data/LATA_WikiCFP.html'.
						^(StandardFileStream fileNamed: mockPath )contentsOfEntireFile
					].

	mockPath:= './GODCallTests_data/TCS_WikiCFP_empty.html'.
	^(StandardFileStream fileNamed: mockPath )contentsOfEntireFile! !

TestCase subclass: #GCConfSearchCrawlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GCConfSearchCrawlerTest methodsFor: 'testing' stamp: 'cms 11/22/2014 15:01'!
testCrawl
	|categories crawler conferences|
	crawler := GCConfSearchCrawler new.
	crawler fetcher: FakeConfSearchFetcher new.
	categories := Dictionary new.
	categories at: 'category' put: 'category'.
	conferences := crawler crawl: categories.
	self assert: conferences size = 32.! !

!GCConfSearchCrawlerTest methodsFor: 'testing' stamp: 'cms 11/22/2014 14:13'!
testParse
	|fileData mockPath conferences crawler conference1 conference2 keywords|
	
	mockPath := './GODCallTests_data/confsearchpage.html'.	
      fileData := (StandardFileStream fileNamed: mockPath ) contentsOfEntireFile.
	crawler := GCConfSearchCrawler new.
	conferences :=  crawler parse: fileData from: 'ia'.
	self assert: (conferences size)  = 32.
	
	conference1 := conferences at: 2.
	conference2 := conferences at: 3.

	self assert: conference1 acronym = 'flairs'.
	self assert: conference1 name = 'The Florida AI Research Society (FLAIRS)'.
	self assert: conference1 url = 'http://www.flairs-28.info/'.
	self assert: (conference1 importantDates) deadlineDate = (Date readFrom: '17 Nov 14' readStream).
	self assert: (conference1 importantDates) startDate = (Date readFrom: '18 May 15' readStream).
	self assert: (conference1 importantDates) endDate = (Date readFrom:'20 May 15' readStream).
	self assert: (conference1 venue) city = 'Hollywood'.
	self assert: (conference1 venue) country = 'USA'. 
	keywords := conference1 keywords.
	self assert: keywords size = 7.
	self assert: (keywords includes: 'knowledge').
	self assert: (keywords includes: 'learning').
	self assert: (keywords includes: 'reasoning').
	self assert: (keywords includes: 'based').
	self assert: (keywords includes: 'using').
	self assert: (keywords includes: 'tutoring').
	self assert: (keywords includes: 'neural').
	self assert: (conference1 categories includes: 'ia').
	self assert: (conference1 edition = 2015).

	self assert: conference2 acronym = 'aia'.
	self assert: conference2 name = 'Artificial Intelligence and Applications'.
	self assert: conference2 url = 'http://www.iasted.org/conferences/home-793.html'.
	self assert: (conference2 importantDates) deadlineDate = (Date readFrom: '03 Dec 12' readStream).
	self assert: (conference2 importantDates) startDate = (Date readFrom: '11 Feb 13' readStream).
	self assert: (conference2 importantDates) endDate = (Date readFrom: '13 Feb 13' readStream).
	self assert: (conference2 venue) city = 'Innsbruck'.
	self assert: (conference2 venue) country = 'Austria'. 
	keywords := conference2 keywords.
	self assert: keywords size = 8.
	self assert: (keywords includes: 'neural').
	self assert: (keywords includes: 'genetic').
	self assert: (keywords includes: 'using').
	self assert: (keywords includes: 'artificial').
	self assert: (keywords includes: 'fuzzy').
	self assert: (keywords includes: 'algorithm').	
	self assert: (keywords includes: 'network').
	self assert: (keywords includes: 'networks').
	self assert: (conference2 categories includes: 'ia').
	self assert: (conference2 edition = 2013).! !

!GCConfSearchCrawlerTest methodsFor: 'testing' stamp: 'cms 10/18/2014 01:17'!
testParseVenue
	|locationString venue crawler|
	crawler := GCConfSearchCrawler new.
	locationString := 'Spain, Tenerife'.
	venue := crawler parseVenue: locationString.
	self assert: venue city = 'Tenerife'.
	self assert: venue country = 'Spain'.

	locationString := 'Spain,'.
	venue := crawler parseVenue: locationString.
	self assert: venue city = nil.
	self assert: venue country = 'Spain'.

	locationString := 'USA, Hollywood, Florida, USA'.
	venue := crawler parseVenue: locationString.
	self assert: venue city = 'Hollywood'.
	self assert: venue country = 'USA'.! !

TestCase subclass: #GCConferenceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GCConferenceTest methodsFor: 'testing' stamp: 'cms 11/22/2014 13:52'!
testComparing
	|conference1 conference2|
	
	conference1 := GCConference new.
	conference2 := GCConference new.
	
	conference1 name: 'Conference 1'.
	conference2 name: 'Conference 1'.
	
	self assert: conference1 = conference2.
	
	conference2 name: 'Conference 2'.
	self assert: conference1 ~= conference2.
	
	conference2 name: conference1 name.
	conference2 acronym: 'c'.
	self assert: conference1 ~= conference2.
		
	conference1 acronym: conference2 acronym.
	self assert: conference1 = conference2.
	
	conference2 edition: '2012'.
	self assert: conference2 ~= conference1.
	
	conference1 edition: conference2 edition.
	self assert: conference2 = conference1.
	
	conference2 url: 'url'.
	self assert: conference2 ~= conference1.
	
	conference1 url: conference2 url.
	self assert: conference2 = conference1.! !

!GCConferenceTest methodsFor: 'testing' stamp: 'pfsm 11/8/2014 19:26'!
testFromSpreadsheet
	"test if given a spreadsheet with conference data it is converted to GODConferences correctly"
	 |godConferencesCollection godConference|
	"when tested, we didnt get a valid spreadsheet"
	godConferencesCollection := GCConference from: (SSSpreadsheetData fromCSV: './GODCallTests_data/conferencesMock.csv').
	
	godConference := godConferencesCollection at: 1.
	self assert: godConference name = 'Artificial Intelligence and Applications'.
	self assert: godConference acronym = 'aia'.
	self assert: godConference venue city = 'Holywood'.
	self assert: godConference venue country = 'USA'..
	self assert: godConference venue place = 'University'.
	self assert: godConference importantDates deadlineDate = '24/03/14'.
	self assert: godConference importantDates startDate = '20/04/14'.
	self assert: godConference importantDates endDate = '25/04/14'.! !

!GCConferenceTest methodsFor: 'testing' stamp: 'cms 11/22/2014 13:35'!
testJoinCollection
	|joined collection|
	collection := OrderedCollection new.
	collection add: 'artificial inteligency'; add: 'computer graphycs'; add: 'sofwtare'.
	joined := GCConference joinCollection: collection.
	self assert: joined = 'artificial inteligency&computer graphycs&sofwtare'.! !

!GCConferenceTest methodsFor: 'testing' stamp: 'cms 11/22/2014 13:42'!
testNormalize
	|acronym|
	acronym := 'Special IEEE Issue Volume 2 ACRONYM 2013'.
	self assert: (GCConference normalizeAcronym: acronym) = 'acronym'.! !

!GCConferenceTest methodsFor: 'testing' stamp: 'cms 11/8/2014 00:57'!
testToSpreadsheet
	
		|collection conference spreadsheet
	sheet row
	conferenceName conferenceAcronym conferenceUrl
	conferenceKeywords conferenceStartDate conferenceEndDate conferenceDeadlineDate 
	conferenceCity conferenceCountry spreadsheetMap|


	conference := GCConference new.
	conferenceAcronym := 'aia'.
	conferenceName := 'Artificial Intelligence and Applications'.
	conferenceKeywords := Set new.
	conferenceKeywords add: 'neural'; add: 'genetic'.
	conferenceUrl:= 'http://conferences'.
	conferenceDeadlineDate := '24 mar 14'.
	conferenceStartDate := '20 abr 14'.
	conferenceEndDate := '25 abr 14'.
	conferenceCity := 'Holywood'.
	conferenceCountry := 'USA'.

	conference acronym: conferenceAcronym.	
	conference name: conferenceName.
	conference url: conferenceUrl.
	conference keywords: conferenceKeywords.
	conference importantDates: GCImportantDates new.
	conference importantDates deadlineDate: conferenceDeadlineDate.	
	conference importantDates startDate: conferenceStartDate.	
	conference importantDates endDate: conferenceEndDate.	
	conference venue: GCVenue new.
	conference venue city: conferenceCity.
	conference venue country: conferenceCountry.
	collection := OrderedCollection new.
	collection add: conference.
	spreadsheet  := GCConference asSpreadsheet: collection.
	sheet := spreadsheet getSheet: 1.
	row := sheet getRow: 1.
	
	spreadsheetMap := GCConference dictionary
	.
     	self assert: (row getCell: (spreadsheetMap at: 'acronym')) value = conferenceAcronym.
     	self assert: (row getCell: (spreadsheetMap at: 'name')) value = conferenceName.
     	self assert: (row getCell: (spreadsheetMap at: 'keywords')) value = 'genetic&neural'.
     	self assert: (row getCell: (spreadsheetMap at: 'url')) value = conferenceUrl.
	self assert: (row getCell: (spreadsheetMap at: 'city')) value = conferenceCity.
	self assert: (row getCell: (spreadsheetMap at: 'country')) value  = conferenceCountry.
	self assert: (row getCell: (spreadsheetMap at: 'deadlineDate')) value = conferenceDeadlineDate.
	self assert: (row getCell: (spreadsheetMap at: 'startDate')) value = conferenceStartDate.
	self assert: (row getCell: (spreadsheetMap at: 'endDate')) value = conferenceEndDate.
	
	
	
	! !

TestCase subclass: #GCCrawlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GCCrawlerTest methodsFor: 'testing' stamp: 'pfsm 11/22/2014 20:20'!
testCategories
	|categories|
	categories := GCCrawler categories.
	self assert: (categories ~= nil).
	self assert: (categories size = 46).
	self assert: (categories includes: 'networks').
	self assert: (categories includes: 'computer graphics').! !

!GCCrawlerTest methodsFor: 'testing' stamp: 'cms 11/9/2014 13:29'!
testMerge
	"class for testing the class method GCCrawler>>merge:with:"

	|conference1 conference2 conference3 mergedConferences|
	conference1 := GCConference new.

	conference1 acronym: 'LATA'.
	conference1 name: '9th INTERNATIONAL CONFERENCE ON LANGUAGE AND AUTOMATA THEORY AND APPLICATIONS'.
	conference1 edition: '2015'.
	conference1 url:  'http://grammars.grlmc.com/lata2015/' asUrl.


	conference1 importantDates: GCImportantDates new.
	(conference1 importantDates) deadlineDate:  ('10 October 2014' asDate).
	(conference1 importantDates) startDate: ('2 Mar 2015' asDate).
	(conference1 importantDates) endDate: ('6 Mar 2015' asDate).

	conference1 venue: GCVenue new.
	(conference1 venue) city: 'Nice'.
	(conference1 venue) country: 'France'. 	
	conference1 categories:  (Set with:  'theoretical computer science' with: 'nlp'). 


	conference2 := GCConference new.
	conference2 acronym: 'LATA'.
	conference2 name: 'Conference on Language and Automata Theory and Applications'.
	conference2 keywords: (Set with: 'lata').
	conference2 edition: '2015'.
	conference2 url:  'http://grammars.grlmc.com/lata2015/' asUrl.
	conference2 content:'Call for papers text'.

	conference2 importantDates: GCImportantDates new.
	(conference2 importantDates) deadlineDate:  ('10 October 2014' asDate).
	(conference2 importantDates) startDate: ('2 Mar 2015' asDate).
	(conference2 importantDates) endDate: ('6 Mar 2015' asDate).

	conference2 venue: GCVenue new.
	(conference2 venue) city: 'Nice'.
	(conference2 venue) country: 'France'. 	
	conference2 categories:  (Set with:  'automata' with:'language'). 


	conference3 := GCConference new.
	conference3 acronym: 'LATA'.
	conference3 rating: (GCRating qualis: 'A2' hIndex: '25').


	mergedConferences := GCCrawler merge: (GCCrawler merge: (Set with: conference1) with: (Set with: conference3 )) with: (Set with: conference2).

	self assert: mergedConferences size = 1.
	self assert: (mergedConferences at: 1) keywords = (#('lata' '9th' 'international' 'conference' 'on' 'language' 'and' 'automata' 'theory' 'and' 'applications') asSet).
	self assert: (mergedConferences at: 1) categories = (Set with: 'language' with:'automata' with:'nlp' with:'theoretical computer science').
	self assert: ((mergedConferences at: 1) rating) qualis = 'A2'.
	self assert: ((mergedConferences at: 1) rating) hIndex = '25'.
	self assert: ((mergedConferences at: 1) venue) city = 'Nice'.
	self assert: ((mergedConferences at: 1) venue) country = 'France'.
	self assert: (mergedConferences at: 1) content = 'Call for papers text'.
	self assert: (mergedConferences at: 1) acronym = 'LATA'.
	self assert: (mergedConferences at: 1)  identifier = 'lata'.
	self assert: (mergedConferences at: 1)  name = '9th INTERNATIONAL CONFERENCE ON LANGUAGE AND AUTOMATA THEORY AND APPLICATIONS'.! !

TestCase subclass: #GCImportantDatesTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GCImportantDatesTest methodsFor: 'testing' stamp: 'cms 11/22/2014 16:56'!
testEquals
	|date1 date2|
	date1 := GCImportantDates new.
	date2 := GCImportantDates new.
	
	date1 deadlineDate: (Date today).
	date2 deadlineDate: (Date yesterday).
	
	self assert: date1 ~= date2.
	
	date2 deadlineDate: (Date today).
	
	self assert: date1 = date2.
	
	date2 startDate: (Date tomorrow).
	
	self assert: date2 ~= date1.
	
	date1 startDate: (date2 startDate).
	
	self assert: date2 = date1.
	
	date2 endDate: (Date tomorrow).
	
	self assert: date2 ~= date1.
	
	date1 endDate: (date2 endDate).
	
	self assert: date2 = date1.
	
	
	! !

TestCase subclass: #GCQualisCrawlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GCQualisCrawlerTest methodsFor: 'testing' stamp: 'cms 11/9/2014 13:46'!
testCrawl
	|source conferences|
	source := GCSourceCreator createQualis.
	conferences := source crawler crawl: source categories.
	self assert: conferences size > 0.
	conferences do: [ :conference |
		self assert: conference acronym ~= nil.
		self assert: conference rating ~= nil.
		self assert: conference rating hIndex ~= nil.
		self assert: conference rating qualis ~= nil.
	]! !

TestCase subclass: #GCSourceCreatorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GCSourceCreatorTest methodsFor: 'testing' stamp: 'cms 11/22/2014 16:35'!
testCreateAll
	|sources|
	sources := GCSourceCreator createAll.
	self assert: sources size = 3.
	sources do:[ :source |
		self assert: (source isKindOf: GCSource).
	].
		! !

!GCSourceCreatorTest methodsFor: 'testing' stamp: 'cms 11/22/2014 16:37'!
testCreateConfSearch
	|source|
	source := GCSourceCreator createConfSearch.
	
	self assert: (source crawler isKindOf: GCConfSearchCrawler).
	self assert: (source categoryFilepath ~= nil).
	self assert: (source categoryFilepath isEmpty not).
	self assert: (source categories isKindOf: Dictionary).
	self assert: source categories keys size > 0.! !

!GCSourceCreatorTest methodsFor: 'testing' stamp: 'cms 11/22/2014 16:38'!
testCreateQualis
	|source|
	source := GCSourceCreator createQualis.
	
	self assert: (source crawler isKindOf: GCQualisCrawler).
	self assert: (source categoryFilepath ~= nil).
	self assert: (source categoryFilepath isEmpty).
	self assert: (source categories isKindOf: Dictionary).
	self assert: source categories keys size = 0.! !

!GCSourceCreatorTest methodsFor: 'testing' stamp: 'cms 11/22/2014 16:38'!
testCreateWikiCfp
	|source|
	source := GCSourceCreator createWikiCfp.
	
	self assert: (source crawler isKindOf: GCWikiCfpCrawler).
	self assert: (source categoryFilepath ~= nil).
	self assert: (source categoryFilepath isEmpty not).
	self assert: (source categories isKindOf: Dictionary).
	self assert: source categories keys size > 0.! !

TestCase subclass: #GCVenueTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GCVenueTest methodsFor: 'testing' stamp: 'cms 11/22/2014 16:59'!
testEquals
	|venue1 venue2|
	venue1 := GCVenue new.
	venue2 := GCVenue new.
	
	venue1 place: 'place'.
	
	self assert: venue1 ~= venue2.
	
	venue2 place: venue1 place.
	
	self assert: venue1 = venue2.
	
	venue1 city: 'City'.
	
	self assert: venue1 ~= venue2.
	
	venue2 city: venue1 city.
	
	self assert: venue2 = venue1.
	
	venue1 country: 'Country'.

	self assert: venue2 ~= venue1.
	
	venue2 country: venue1 country.
	
	self assert: venue1 = venue2.
	! !

TestCase subclass: #GCWikiCfpCrawlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GCWikiCfpCrawlerTest methodsFor: 'testing' stamp: 'pfsm 11/22/2014 21:21'!
testCrawl
	|categories crawler conferences|

	crawler := GCWikiCfpCrawler new.
	crawler fetcher: FakeWikiCfpFetcher new.
	categories := Dictionary new.
	categories at: 'theoretical computer science' put: 'theoretical computer science'.
	conferences := crawler crawl: categories.

	self assert: conferences size = 2.
	self assert: (conferences at:1) identifier = 'cade'.
	self assert: (conferences at:1) name = '25th International Conference on Automated Deduction'.
	self assert: (conferences at:2) identifier = 'lata'.
	self assert: (conferences at:2) name = '9th INTERNATIONAL CONFERENCE ON LANGUAGE AND AUTOMATA THEORY AND APPLICATIONS'.! !

!GCWikiCfpCrawlerTest methodsFor: 'testing' stamp: 'pfsm 10/21/2014 00:30'!
testParse	
	"method for testing GCWikiCfpCrawler>>parse"

	| conference1 conference2  mockPath fileData crawler|
	
	mockPath := './GODCallTests_data/wikicfppage_conference1.html'.	
     fileData := (StandardFileStream fileNamed: mockPath ) contentsOfEntireFile.
	crawler := GCWikiCfpCrawler new.
	conference1 := crawler parse: fileData.

	self assert: conference1 acronym = 'LATA'.
	self assert: conference1 name = '9th INTERNATIONAL CONFERENCE ON LANGUAGE AND AUTOMATA THEORY AND APPLICATIONS'.
	self assert: conference1 edition = '2015'.
	self assert: (conference1 url) asString = 'http://grammars.grlmc.com/lata2015/'.
	self assert: (conference1 importantDates) deadlineDate = ('10 October 2014' asDate).
	self assert: (conference1 importantDates) startDate = ('2 Mar 2015' asDate).
	self assert: (conference1 importantDates) endDate = ('6 Mar 2015' asDate).
	self assert: (conference1 venue) city = 'Nice'.
	self assert: (conference1 venue) country = 'France'. 	
	self assert: (conference1 categories)  =  (Set with:  'theoretical computer science' with: 'nlp'). 	



	mockPath := './GODCallTests_data/wikicfppage_conference2.html'.	
     fileData := (StandardFileStream fileNamed: mockPath ) contentsOfEntireFile.
	crawler := GCWikiCfpCrawler new.
	conference2 := crawler parse: fileData.

	self assert: conference2 acronym = 'LICS'.
	self assert: conference2 name = '28th Annual ACM/IEEE Symposium on Logic In Computer Science'.
	self assert: conference2 edition = '2013'.
	self assert: (conference2 url) asString = 'http://www2.informatik.hu-berlin.de/lics/lics13/'.
	self assert: (conference2 importantDates) deadlineDate = ('2013-01-07' asDate).
	self assert: (conference2 importantDates) startDate = ('2013-06-25' asDate).
	self assert: (conference2 importantDates) endDate = ('2013-06-28' asDate).
	self assert: (conference2 venue) city = 'New Orleans'.
	self assert: (conference2 venue) country = 'USA'. 	
	self assert: (conference2 categories)  =  (Set with:  'theoretical computer science' with: 'logic'). 	
! !

!GCWikiCfpCrawlerTest methodsFor: 'testing' stamp: 'pfsm 11/22/2014 20:37'!
testUrlsFrom
	"method for testing GCWikiCfpCrawler>>urlsFrom"
	| crawler TCSUrl OSUrl urlList categories|

	TCSUrl:= 'http://www.wikicfp.com/cfp/call?conference=theoretical%20computer%20science'. 
	OSUrl:= 'http://www.wikicfp.com/cfp/call?conference=operating%20systems'. 

	categories := Dictionary new.
	categories at: 'theoretical computer science' put: 'theoretical computer science'.
	categories at: 'operating systems' put: 'operating systems'.

	crawler := GCWikiCfpCrawler new.
	urlList:= crawler urlsFrom: categories.

	self assert: (urlList size = 2).
	self assert: ((urlList at:1) asString = TCSUrl).
	self assert: ((urlList at:2) asString = OSUrl).
	! !

TestCase subclass: #GODCallTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GODCallTest methodsFor: 'generating' stamp: 'pfsm 11/8/2014 19:38'!
generateConferences
	"generate a list of conferences from html files"
	|mockPath fileData crawler conferences|

	crawler := GCWikiCfpCrawler new.

	mockPath := './GODCallTests_data/wikicfppage_conference1.html'.	
     fileData := (StandardFileStream fileNamed: mockPath ) contentsOfEntireFile.

	conferences := OrderedCollection new.	
	
	conferences add: (crawler parse: fileData).

	mockPath := './GODCallTests_data/wikicfppage_conference2.html'.	
     fileData := (StandardFileStream fileNamed: mockPath ) contentsOfEntireFile.

	conferences add: (crawler parse: fileData).


	mockPath := './GODCallTests_data/wikicfppage_conference3.html'.	
     fileData := (StandardFileStream fileNamed: mockPath ) contentsOfEntireFile.

	conferences add: (crawler parse: fileData).

^ conferences.! !

!GODCallTest methodsFor: 'testing' stamp: 'pfsm 11/22/2014 19:32'!
testCategories
	|godCall categories|
	"categories := #('test1', 'test2', 'test3')."
	categories:= Set with:'test1' with:'test2' with:'test3'.
	godCall := GODCall new.
	godCall categories: categories.
	self assert: godCall categories = categories.! !

!GODCallTest methodsFor: 'testing' stamp: 'pfsm 11/7/2014 17:40'!
testConferencesFilter
	"emulate a user's search"

	|filteredConferences  searchFilter  conferences filter|

	searchFilter := GCSearchFilter new.
	searchFilter keywords: (GODCall extractKeywordsFrom: '9th INTERNATIONAL CONFERENCE ON LANGUAGE AND AUTOMATA THEORY AND APPLICATIONS').
	searchFilter categories: (Set with:  'theoretical computer science' with: 'nlp').
	searchFilter startDate: (Date year:2010 month: 1 day: 1).
	searchFilter endDate: (Date year:2015 month: #December  day: 1).
	searchFilter deadlineDate: (Date year:2015 month: #December  day: 1).

	conferences := self generateConferences.

	filter:= FILTConferenceFilter new.
	
	filteredConferences := filter filter: conferences byGCSearchFilter: searchFilter.	
	
	self assert: filteredConferences size = 1.
	self assert: (filteredConferences at: 1) acronym = 'LATA'.
	self assert: (filteredConferences at: 1) name = '9th INTERNATIONAL CONFERENCE ON LANGUAGE AND AUTOMATA THEORY AND APPLICATIONS'.
	self assert: (filteredConferences at: 1) edition = '2015'.
	self assert: ((filteredConferences at: 1) url) asString = 'http://grammars.grlmc.com/lata2015/'.
	self assert: ((filteredConferences at: 1) importantDates) deadlineDate = ('10 October 2014' asDate).
	self assert: ((filteredConferences at: 1) importantDates) startDate = ('2 Mar 2015' asDate).
	self assert: ((filteredConferences at: 1) importantDates) endDate = ('6 Mar 2015' asDate).
	self assert: ((filteredConferences at: 1) venue) city = 'Nice'.
	self assert: ((filteredConferences at: 1) venue) country = 'France'. 	
	self assert: ((filteredConferences at: 1) categories)  =  (Set with:  'theoretical computer science' with: 'nlp'). 	

	
! !

!GODCallTest methodsFor: 'testing' stamp: 'pfsm 11/8/2014 20:28'!
testConferencesFilterByCategory
	"emulate a user's search by categories"

	|filteredConferences  searchFilter  conferences filter|

	filter:= FILTConferenceFilter new.
	searchFilter := GCSearchFilter new.
	conferences := self generateConferences.
	self assert: conferences size = 3.

	searchFilter categories: (Set with:  'theoretical computer science').
	filteredConferences := filter filter: conferences byGCSearchFilter: searchFilter.	
	self assert: filteredConferences size = 2.
	filteredConferences do:[:conference | self assert:(conference categories includes:'theoretical computer science')].

	searchFilter categories: (Set with:  'logic').
	filteredConferences := filter filter: conferences byGCSearchFilter: searchFilter.	
	self assert: filteredConferences size = 2.
	filteredConferences do:[:conference | self assert:(conference categories includes:'logic')].


	searchFilter categories: (Set with:  'nlp').
	filteredConferences := filter filter: conferences byGCSearchFilter: searchFilter.	
	self assert: filteredConferences size = 1.
	filteredConferences do:[:conference | self assert:(conference categories includes:'nlp')].

	searchFilter categories: (Set with:  'theoretical computer science' with:'logic').
	filteredConferences := filter filter: conferences byGCSearchFilter: searchFilter.	
	self assert: filteredConferences size = 3.
	filteredConferences do:[:conference | 	self assert:(conference categories includesAnyOf: (Set with:  'theoretical computer science' with:'logic'))].
	
! !

!GODCallTest methodsFor: 'testing' stamp: 'pfsm 11/8/2014 20:25'!
testConferencesFilterByDates
	"emulate a user  searching for  conferences in 2015 "

	|filteredConferences  searchFilter  conferences filter|

	filter:= FILTConferenceFilter new.
	searchFilter := GCSearchFilter new.
	conferences := self generateConferences.
	self assert: conferences size = 3.

	searchFilter startDate: (Date year:2015 month: 1 day: 1).
	searchFilter endDate: (Date year:2015 month: 12 day: 31).
	filteredConferences := filter filter: conferences byGCSearchFilter: searchFilter.	
	self assert: filteredConferences size = 2.
	filteredConferences do:[:conference | 	self assert:(conference importantDates startDate >= (Date year:2015 month: 1 day: 1)).
															self assert:(conference importantDates endDate <= (Date year:2015 month: 12 day: 31))].

! !

!GODCallTest methodsFor: 'testing' stamp: 'pfsm 11/8/2014 20:25'!
testConferencesFilterBySearchKey
	"emulate a user's search that contains a search key "

	|filteredConferences  searchFilter  conferences filter searchKey|

	filter:= FILTConferenceFilter new.
	searchFilter := GCSearchFilter new.
	conferences := self generateConferences.
	self assert: conferences size = 3.

	searchKey := 'international conference'.

	searchFilter keywords: (GODCall extractKeywordsFrom: searchKey).
	filteredConferences := filter filter: conferences byGCSearchFilter: searchFilter.	
	self assert: filteredConferences size = 2.
	filteredConferences do:[:conference | self assert:(conference keywords includesAllOf: (Set with:'international' with:'conference') )].

! !
